function [yarray, t, channelmap, stripnummap, metadata, metadescription, metakey, outname] = readsingleset(thecase,setnumber,Nframes)
% function [yarray, t, channelmap, stripnummap, metadata, metadescription, metakey, outname] = readsingleset(thecase,setnumber,Nframes)
% 
% loads particular (<setnumber>) set of *.wfm files saved by Tektronix TDS5000/B, TDS6000/B/C,
% or TDS/CSA7000/B, MSO70000/C, DSA70000/B/C DPO70000/B/C DPO7000/ MSO/DPO5000
% instrument families into the variables <yarray> (y data) and <t> (time data).
% 
% The set of *.wfm files needs to be described in <themetadata.m> file.
% <thecase> parameter defines the set of the files.
% <Nframes> parameter shows how many frames each channel of the set contains.
% <yarray> is three dimensional array with size number of channels times <Nframes>
% times number of data points in the frame.
% <t> is one dimensional array containing certain number of data points.
% 
% The function uses <readNfastframes.m> and <themetadata.m> files.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% All file names consist of four parts: path to the directory (<pname>), <filenamebase>,
% set number identifier (<fnumbertag>), and <endtag>. The first two parts are defined in metadata.
% The others depend on <setnumber> and <thecase>.
% 
% Metadata reading.
[pname, filenamebase, namecase, outname, nchannels, channelmap, stripnummap, metadata, metadescription, metakey] = themetadata(thecase);

outname

% <fnumbertag> definition.
fnumbertag='der';
nfs = int2str(setnumber);
if(namecase==1)
    fnumbertag = nfs;
else
    fnumbertag = ['_' nfs];
end

% Names of the files without <endtag>.
almostfullfilename = [ pname filenamebase fnumbertag ];

% Reading of the first channel for <yarray> size definition.
testcasename='der';
if(namecase==1)
    testcasename = [almostfullfilename '_Ch1.wfm'];
else
    testcasename = [almostfullfilename '.wfmCH1.wfm'];
end

[testcasearray, t] = readNfastframes(testcasename, Nframes);
[size1,size2] = size(testcasearray);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Loading all channels to <yarray>.
yarray = zeros(nchannels,size1,size2);

for nc=1:nchannels
   
    endtag = 'der';
    ncs = int2str(channelmap(nc));
    if(namecase==1)
        endtag = ['_Ch' ncs '.wfm'];
    else
        endtag = ['.wfmCH' ncs '.wfm'];
    end
    fullname=[almostfullfilename endtag];
    
    [singlearray, t] = readNfastframes(fullname, Nframes);
    
    yarray(nc,:,:) = singlearray;
end

end
