%% uigetfile: a file selector
%% A list of files is displayed, and a prompt requests user's choice.
%% Whenever kdialog (KDE) or zenity (Gnome) are present, a nice file selector 
%% will be opened.
%%
%% Usage:
%%   [filename, pathname, filterindex ] = uigetfile(filter, title);
%% If dialog is canceled, then zeros are returned.
%%
%% Example:
%%   [fname, pname ] = uigetfile('*.m', 'Select an m-file');
%%
%% Author: Petr Mikulik, Emmanuel Farhi
%% Version: October 2009
%% License: Free as much as possible / public domain.

function [a, b, c] = uigetfile (files, title)

  if nargin==0 files='*'; end
  if nargin<2 title='Choose file'; end

  a=0; b=[];

  c=1; % no support for file filters more than 1

  if isempty(b)
    % try with Zenity
    [a,b]=system([ 'zenity --file-selection --filename=''', files, ''' --title="', title, '"' ]);
    if a==1 && isempty(b), return; end % User pressed Cancel
  end

  if isempty(b)
    % try with Kdialog
    [a,b]=system(['kdialog --getopenfilename . ''', files, ''' --title "', title, '"']);
    if a==1 && isempty(b), return; end % User pressed Cancel
  end

  if isempty(b)
    b=dir(files);
    if isempty(b)
        fprintf('No (such) file available.');
        a=0; b=0; c=0;
        return
    end
    fprintf('\n=== [%s: %s] ===\n', title, files);
    for index=1:length(dir)
      if ~b(index).isdir
        if b(index).bytes > 1073741824
          fprintf('[%7f Gb][%s] %s\n', b(index).bytes/1073741824, b(index).date, b(index).name);
        else
          fprintf('[%10i][%s] %s%c\n', b(index).bytes, b(index).date, b(index).name,filesep);
        end
      else
        fprintf('[%s][%s] %s%c\n', ' Directory', b(index).date, b(index).name,filesep);
      end
    end
    b=input('Please enter filename: (RETURN to Cancel)', 's');
    if ~exist(b, 'file') b={}; end
    a='';
    if length(b)>0 && b(1)~=filesep b=[pwd, filesep, b]; end
  end

  if ~isempty(b)
    if b(end)=="\n" b=b(1:end-1); end
  end

  % no file selected => a and b are zeros
  if isempty(b)
      a=0; b=0; c=0;
      return
  end

  % split b into name and path
  k=rindex(b, filesep());
  a=b(k+1:end);
  b=b(1:k);

endfunction

% eof uigetfile.m
