function [yarray, taxis, baselinearray, sigmax, channelmap, stripnummap, maxstrip, maxchannel, metadata, metadescription, metakey] = wfmsets2rawmatsets(thecase,Nframes,Nfiles)
% function [yarray, taxis, baselinearray, sigmax, channelmap, stripnummap, maxstrip, maxchannel, metadata, metadescription, metakey] = wfmsets2rawmatsets(thecase,Nframes,Nfiles)
% 
% loads data from *.wfm files to <yarray> using all channels and all files.
% All this data is saved in the file in matlab format.
% 
% <Nframes> is number of frames in each file.
% <Nfiles> is number of files per channel.
% <thecase> parameter specifies the metadata.
% 
% <yarray> is three dimensional array number of channels times <Nframes>*<Nfiles> times 
% number of data points with y data.
% <taxis> is time data.
% <baselinearray> contains information about the average and standard deviation values of each frame.
% <sigmax> is maximum of the signal in each frame.
% <maxchannel> shows which channel has maximum signal for each frame.
% <maxstrip> shows which strip has maximum signal for each frame.
% 
% The function uses <readsingleset.m> and <baselinecalc.m> files.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reading a set of data for determinimg of number of channels and number of data points per frame.
% Metadata is defined too.
[testarray, taxis, channelmap, stripnummap, metadata, metadescription, metakey, outname] = readsingleset(thecase,1,Nframes);
[dummy,nchannels] = size(channelmap);
[size1,size2,size3]=size(testarray);	% size1 == nchannels

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Arrays declaration
yarray = zeros(size1,(Nfiles*Nframes),size3);
sigmax = zeros(nchannels,(Nfiles*Nframes));
maxstrip = zeros((Nfiles*Nframes),1);
maxchannel = zeros((Nfiles*Nframes),1);
baselinearray = zeros(nchannels,2,(Nfiles*Nframes));

nchannels

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Loading all frames from all files for each channel into <yarray>.
for nf=1:Nfiles

    [singlearray, taxis, channelmap, stripnummap, metadata, metadescription, metakey, outname] = readsingleset(thecase,nf,Nframes);

    fnumbertag = int2str(nf);
    
    for nch=1:nchannels
         yarray(nch, (((nf-1)*Nframes)+1):((nf*Nframes)), :) = -singlearray(nch, :, :);
    end
    
    nf

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
txt='calculating baselines and signal maxes'

for nch=1:nchannels
    [bl,blsig,wmax] = baselinecalc(squeeze(yarray(nch,:,:)),100);
    baselinearray(nch,1,:) = bl(:);
    baselinearray(nch,2,:) = blsig(:);
    sigmax(nch,:) = wmax(:);       
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
txt = 'finding max stripline'
 
  for nch=1:nchannels
      whichmax = ones(1,Nfiles*Nframes);
      for mch=1:nchannels
           if(nch~=mch)
               whichmax = whichmax.*(sigmax(nch,:)>sigmax(mch,:));
           end
      end
  
      maxchannel = maxchannel + nch*(whichmax');   
      maxstrip = maxstrip + (stripnummap(nch))*(whichmax');
  end


%matfilename = [ pname filenamebase '.mat']
clear nf fnumbertag size1 size2 size3 dummy testarray singlearray pname fnamebase namecase Nframes Nfiles filenamebase nch txt whichmax;
clear mch;
outname
save(outname);


end
